@@ -1,10 +1,10 @@
-#!/usr/bin/python2.7
+#!/usr/bin/python3
+"""
+Univention Common Python Library for file locking
+"""
+# Copyright 2011-2021 Univention GmbH
 #
-# Univention Common Python Library
-#
-# Copyright 2011-2017 Univention GmbH
-#
-# http://www.univention.de/
+# https://www.univention.de/
 #
 # All rights reserved.
 #
@@ -27,29 +27,38 @@
 # You should have received a copy of the GNU Affero General Public
 # License with the Debian GNU/Linux or Univention distribution in file
 # /usr/share/common-licenses/AGPL-3; if not, see
-# <http://www.gnu.org/licenses/>.
+# <https://www.gnu.org/licenses/>.
+
+from __future__ import print_function
 
 import fcntl
 import os
+from typing import IO, Optional, Text  # noqa F401
 
 
 def get_lock(name, nonblocking=False):
+	# type: (str, bool) -> Optional[IO[Text]]
 	"""
-	get_lock() returns a filedescriptor for a lock file after the file
-	has been locked exclusively. In non-blocking mode None is returned
-	if the lock cannot be gained.
-	The returned filedescriptor has to be kept. Otherwise the lock will
-	be release automatically on filedescriptor's destruction.
+	Get a exclusive lock.
+
+	:param str name: The name for the lock file.
+	:param bool nonblocking: Return `None` instead of waiting indefinitely to get the exclusive lock if the lock is already taken.
+
+	:returns: a file descriptor for a lock file after the file has been locked exclusively. In non-blocking mode `None` is returned if the lock cannot be gained.
+	:rtype: file or None
+
+	The returned file descriptor has to be kept. Otherwise the lock will
+	be release automatically on file descriptor's destruction.
 
 	>>> fd = get_lock('myapp')
-	>>> ...... do some critical stuff ......
+	>>> # ...... do some critical stuff ......
 	>>> release_lock(fd)
 	>>>
 	>>> fd = get_lock('myapp', nonblocking=True)
 	>>> if not fd:
-	>>>     print 'cannot get lock'
+	>>>     print('cannot get lock')
 	>>> else:
-	>>>     ...... do some critical stuff ......
+	>>>     # ...... do some critical stuff ......
 	>>>     release_lock(fd)
 	"""
 	fn = "/var/run/%s.pid" % name
@@ -63,13 +72,17 @@ def get_lock(name, nonblocking=False):
 		if e.errno == 11:
 			return None
 		raise
-	print >>fd, '%s\n' % os.getpid()
+	fd.write('%s\n' % os.getpid())
+	fd.flush()
 	return fd
 
 
 def release_lock(fd):
+	# type: (IO[Text]) -> None
 	"""
-	release_lock() releases a previously gained lock.
+	Releases the previously gained lock.
+
+	:param file fd: The file descriptor of the lock file.
 	"""
 	fcntl.lockf(fd, fcntl.LOCK_UN)
 	fd.close()
